Learn R Programming

ncdf4.helpers (version 0.3-7)

nc.get.climatology.bounds.var.list: Get a list of names of climatology bounds variables

Description

Get a list of names of climatology bounds variables.

Usage

nc.get.climatology.bounds.var.list(f)

Value

A character vector naming all of the climatology bounds variables found.

Arguments

f

The file (an object of class ncdf4)

Details

The CF metadata convention defines a climatology attribute which can be applied to a time axis to indicate that the data is climatological in nature; the value of this attribute is the name of another variable in the file which defines the bounds of each climatological time period. This function returns the names of any climatology bounds variables found in a file.

References

http://cfconventions.org/Data/cf-conventions/cf-conventions-1.8/cf-conventions.html#climatological-statistics

Examples

Run this code
## Get list of climatology bounds variables
if (FALSE) {
f <- nc_open("pr.nc")
clim.bounds <- nc.get.climatology.bounds.var.list(f)
nc_close(f)
}

Run the code above in your browser using DataLab