Learn R Programming

ncdf4.helpers (version 0.3-7)

nc.get.compress.dims: Get X and Y dimension variables for reduced (compressed) grids

Description

Get X and Y dimension variables for reduced (compressed) grids.

Usage

nc.get.compress.dims(f, v)

Value

A list consisting of two members of class ncdim4: x.dim for the X axis, and y.dim for the Y axis.

Arguments

f

The file (an object of class ncdf4)

v

The name of a variable

Details

The CF metadata convention defines a method for implementing reduced grids (grids missing pieces of themselves); they call this compression by gathering. This function retrieves the X and Y dimensions for reduced (compressed) grids, returning a list containing the X and Y dimensions.

References

http://cfconventions.org/Data/cf-conventions/cf-conventions-1.8/cf-conventions.html#reduced-horizontal-grid

Examples

Run this code
## Get compress dimensions from file.
if (FALSE) {
f <- nc_open("pr.nc")
compress.dims <- nc.get.compress.dims(f, "pr")
nc_close(f)
}

Run the code above in your browser using DataLab