nc.get.coordinate.axes: Get a list of dimension variables and axes for a variable's coordinate variable
Description
Get a list of dimension variables and axes for a variable's coordinate variable.
Usage
nc.get.coordinate.axes(f, v)
Value
A named character vector containing axes, the names of which are the corresponding dimension variables.
Arguments
f
The file (an object of class ncdf4)
v
The name of a variable
Details
The CF metadata standard defines a convention for definining 2-dimensional variables to accompany pairs of dimension variables. Usually these are latitude and longitude variables, and accompany projected grids. This function returns a named list of axes, the names of which are the associated dimension variables.