nc.get.dim.bounds.var.list: Get a list of names of dimension bounds variables.
Description
Get a list of names of dimension bounds variables.
Usage
nc.get.dim.bounds.var.list(f, v = NULL)
Value
A character vector naming all of the dimension bounds variables found.
Arguments
f
The file (an object of class ncdf4).
v
The name of the variable (a string).
Details
Many dimension variables are not single points, but in fact represent a range along the axis. This is expressed by associated dimension bounds variables. This function returns the names of any dimension bounds variables found in a file.