Learn R Programming

ncdf4.helpers (version 0.3-7)

nc.get.dim.names: Get a list of names of dimensions

Description

Get a list of names of dimensions.

Usage

nc.get.dim.names(f, v)

Value

A character vector naming the dimensions found.

Arguments

f

The file (an object of class ncdf4)

v

Optionally, a variable

Details

This function returns the names of dimensions in a file or, if v is also supplied, attached to a particular variable.

Examples

Run this code
## Get dimension names
if (FALSE) {
f <- nc_open("pr.nc")
dim.names <- nc.get.dim.names(f, "pr")
nc_close(f)
}

Run the code above in your browser using DataLab