Optionally, the variable to look for a time dimension on.
time.dim.name
Optionally, the time dimension name.
correct.for.gregorian.julian
Specific workaround for Gregorian-Julian calendar transitions in non-proleptic Gregorian calendars
return.bounds
Whether to return the time bounds as an additional attribute
Details
Retrieving time data from a NetCDF file in an intelligible format is a non-trivial problem. The PCICt package solves part of this problem by allowing for 365- and 360-day calendars. This function complements it by returns time data for a file as PCICt, doing all necessary conversions.