powered by
Gets a data subset in the place described by the named list of axes.
nc.get.var.subset.by.axes(f, v, axis.indices, axes.map = NULL)
An object of class ncdf4 which represents a NetCDF file.
ncdf4
A string naming a variable in a file or an object of class ncvar4.
ncvar4
A list consisting of zero or more vectors of indices, named by which axis they refer to (X, Y, T, etc).
An optional vector mapping axes to NetCDF dimensions. If not supplied, it will be generated from the file.
This function will read data from the specified file (f) and variable (v) at the location specified by axis.indices.
f
v
axis.indices
ncdf4.helpers-package
## Get a subset of the data. if (FALSE) { f <- nc_open("pr.nc") dat <- nc.get.var.subset.by.axes(f1, "pr", list(X=1:4, Y=c(1, 3, 5))) nc_close(f) }
Run the code above in your browser using DataLab