Learn R Programming

ncdf4.helpers (version 0.3-7)

nc.is.regular.dimension: Determine if a dimension is regular

Description

Determine if a dimension is regular (evenly spaced).

Usage

nc.is.regular.dimension(d, tolerance = 1e-06)

Value

TRUE if the data is regular; FALSE if not.

Arguments

d

The data to be tested

tolerance

The tolerance for variation in step size, as a fraction of the step size.

Details

Not all dimensions or data are regular (evenly spaced). This function will, given data and optionally a tolerance level, determine if the dimension is regular or not.

Examples

Run this code
dat <- c(1, 2, 3, 4, 5, 6, 7)
## TRUE
nc.is.regular.dimension(dat)

dat[7] <- 7.001
## FALSE
nc.is.regular.dimension(dat)

Run the code above in your browser using DataLab