nc.make.time.bounds: Creates time bounds for a time series
Description
Creates time bounds for a time series.
Usage
nc.make.time.bounds(ts, unit = c("year", "month"))
Value
2-dimensional bounds array for the time values with dimensions [length(ts), 2].
Arguments
ts
The time values, of type PCICt
unit
The units to be used.
Details
When aggregating data along the time axis, it is occasionally useful to be able to generate bounds for that data. This function will, given a time series of PCICt, returns a set of bounds for that time series based the supplied units.