powered by
Get step size for data.
get.f.step.size(d, f)
The step size
The data to have the step size determined
The function to aggregate the step size
Gets the step size for data, aggregated by the supplied function. This is useful when you want to know the mean timestep size, median, minimum, range, etc for the purposes of classifying data by time resolution.
dat <- c(1, 2, 3, 4, 5, 7) ## Will be 2 max.step.size <- get.f.step.size(dat, max) ## Will be 1 min.step.size <- get.f.step.size(dat, min)
Run the code above in your browser using DataLab