nc.get.compress.dims: Get X and Y dimension variables for reduced (compressed) grids
Description
Get X and Y dimension variables for reduced (compressed) grids.
Usage
nc.get.compress.dims(f, v)
Value
A list consisting of two members of class ncdim4: x.dim for the X axis, and y.dim for the Y axis.
Arguments
f
The file (an object of class ncdf4)
v
The name of a variable
Details
The CF metadata convention defines a method for implementing reduced grids (grids missing pieces of themselves); they call this compression by gathering. This function retrieves the X and Y dimensions for reduced (compressed) grids, returning a list containing the X and Y dimensions.