powered by
Get a list of names of dimensions.
nc.get.dim.names(f, v)
A character vector naming the dimensions found.
The file (an object of class ncdf4)
ncdf4
Optionally, a variable
This function returns the names of dimensions in a file or, if v is also supplied, attached to a particular variable.
v
## Get dimension names if (FALSE) { f <- nc_open("pr.nc") dim.names <- nc.get.dim.names(f, "pr") nc_close(f) }
Run the code above in your browser using DataLab